# Overview
Juju charm for python-moinmoin, charm author: Patrick Hetu <patrick@koumbit.org>

# Deployment
After a successful bootstrap, you can deploy the service without a configuration or alias with:

    juju deploy python-moinmoin
    juju expose python-moinmoin

Though, it's recommended you create a yaml file with your parameters, for instance if you were to deploy the service as "mywiki", the configuration would look like:

    mywiki:
      wiki_name : "My MoinMoin wiki"
      admin_name: "Admin"
      languages: English French
      xapian_search: True
      listen_port: 80

To then deploy the wiki, with pre-seeded configuration:

    juju deploy --config mywiki.yaml python-moinmoin mywiki
    juju expose mywiki

# Configuration
This service contains several configuration options for controlling the moinmoin install

## wiki_name
Set the name and title of the wiki

    juju set python_moinmoin wiki_name="My new wiki name"

## admin_name
Name of the admin account

    juju set python_moinmoin admin_name="Adminstrator"

## languages
List of languages to be installed on the wiki, space delimited

    juju set python_moinmoin languages English Spanish French

To remove a language you'll need to re-enter the entire list, removing the language you no longer want

    juju set python_moinmoin languages="English Spanish"

# xapian_serach
Enable xapian serach on your wiki (True or False)

    juju set python_moinmoin xapian_search="True"

# listen_port
The port moinmoin should listen on. By default it's 8080

    juju set python_moinmoin listen_port=80

# use_openid
Setting to say if the wiki is using OpenID authentication or not.

    juju set python_moinmoin use_openid=True

# openidrp_authorized_teams
What OpenID teams are authorized to log in, if use_openid is true.

   juju set python_moinmoin openidrp_authorized_teams="['team1', 'team2']"

# Relations
python-moinmoin can be related to any of the proxy charms, including but not limited to: haproxy, varnish, and squid. An example of connecting squid-reverseproxy to python-moinmoin is listed below:

    juju deploy squid-reverseproxy squid
    juju unexpose python-moinmoin
    juju add-relation python-moinmoin squid
    juju expose squid
